<?php

namespace Liteerp\Appointment\Providers;

use Illuminate\Support\ServiceProvider;

class AppointmentServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'appointment');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'appointment');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        // Bind facade
        $this->app->bind('liteerp.appointment', function ($app) {
            return $this->app->make('Liteerp\Appointment\Appointment');
        });

                // Bind Appointment to repository
        $this->app->bind(
            'Liteerp\Appointment\Interfaces\AppointmentRepositoryInterface',
            \Liteerp\Appointment\Repositories\Eloquent\AppointmentRepository::class
        );

        $this->app->register(\Liteerp\Appointment\Providers\AuthServiceProvider::class);
        
        $this->app->register(\Liteerp\Appointment\Providers\RouteServiceProvider::class);
                
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['liteerp.appointment'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('liteerp/appointment.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/appointment')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/appointment')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
